@@ -2,18 +2,15 @@ package Stuff::Util;
 
 use Stuff::Features;
 use Carp;
+use Scalar::Util qw/ blessed reftype refaddr /;
 use Exporter 'import';
 
-our @EXPORT_OK = qw/ plainize is_package_name load_module /;
+our @EXPORT_OK = qw/ plainize load_module clone /;
 
 sub plainize {
   map { ref $_ eq 'ARRAY' ? map { plainize( $_ ) } @$_ : $_; } @_;
 }
 
-sub is_package_name($) {
-  $_[0] =~ /^([a-z_][a-z_0-9]*::)*[a-z_][a-z_0-9]*$/i;
-}
-
 sub load_module($;$) {
   my( $package, $dh ) = @_;
   
@@ -28,7 +25,7 @@ sub load_module($;$) {
       unless length $package;
     
     croak( qq/Bad package name "$package"/ )
-      unless is_package_name $package;
+      unless $package =~ /^([a-z_][a-z_0-9]*::)*[a-z_][a-z_0-9]*$/i;
     
     require $module;
   };
@@ -44,7 +41,6 @@ sub load_module($;$) {
 }
 
 sub clone {
-  
 }
 
 1;
@@ -58,8 +54,7 @@ Stuff::Util
   use Stuff::Util ':all';
   
   load_module( 'Some::Module' );  
-  is_package_name( 'Some::Module' );
-  plainize( [ 10, [ 0, 2, 4, [ 5, 6, 7 ] ] ]); # => ( 10, 0, 2, 4, 5, 6, 7 )
+  plainize( [ 10, [ 0, 2, 4, [ 5, 6, 7 ] ] ] ); # => ( 10, 0, 2, 4, 5, 6, 7 )
 
 =head1 FUNCTIONS
 
@@ -77,7 +72,8 @@ If any error happen duering loading, this error will be thrown.
   load_module( 'ModuleWithError' ); # dies
 
 Second optional argument defines "error handler" or "exception converter".
-The only purpose for it is conversion of standart perl error into your custom error object. Like this:
+The only purpose for it is conversion of standart perl error into your custom error object.
+Like this:
 
   use Scalar::Util 'blessed';
   
@@ -86,9 +82,9 @@ The only purpose for it is conversion of standart perl error into your custom er
     $exception_class->throw( $@ );
   } );
 
-head2 C<is_package_name>
+=head2 C<plainize>
 
-head2 C<plainize>
+  plainize( @list );
 
 =head1 AUTHOR
 
